aboutsummaryrefslogtreecommitdiff
path: root/ci
diff options
context:
space:
mode:
authorNirbheek Chauhan <nirbheek@centricular.com>2021-08-16 18:11:15 +0530
committerXavier Claessens <xclaesse@gmail.com>2021-08-16 10:36:13 -0400
commitc95bffb295dd8ae12dd37c9a6c33372a20cf9a68 (patch)
tree6446946b8e4ae0adbc57094346c19bfe17a688f2 /ci
parentf0b16e4e837aa69ca5924568e09880ad49e4997e (diff)
downloadmeson-c95bffb295dd8ae12dd37c9a6c33372a20cf9a68.zip
meson-c95bffb295dd8ae12dd37c9a6c33372a20cf9a68.tar.gz
meson-c95bffb295dd8ae12dd37c9a6c33372a20cf9a68.tar.bz2
ci: Use 32-bit Rust and Python on vs2017 x86
See also: https://github.com/mesonbuild/meson/issues/9038#issuecomment-898960933
Diffstat (limited to 'ci')
-rw-r--r--ci/run.ps113
1 files changed, 11 insertions, 2 deletions
diff --git a/ci/run.ps1 b/ci/run.ps1
index a0b9479..5f25685 100644
--- a/ci/run.ps1
+++ b/ci/run.ps1
@@ -7,8 +7,17 @@ if ($LastExitCode -ne 0) {
# remove PostgreSQL from path so we don't pickup a broken zlib from it
$env:Path = ($env:Path.Split(';') | Where-Object { $_ -notmatch 'mingw|Strawberry|Chocolatey|PostgreSQL' }) -join ';'
-# Rust puts its shared stdlib in a secret place, but it is needed to run tests.
-$env:Path += ";$HOME/.rustup/toolchains/stable-x86_64-pc-windows-msvc/bin"
+if ($env:arch -eq 'x64') {
+ # Rust puts its shared stdlib in a secret place, but it is needed to run tests.
+ $env:Path += ";$HOME/.rustup/toolchains/stable-x86_64-pc-windows-msvc/bin"
+} elseif ($env:arch -eq 'x86') {
+ # Switch to the x86 Rust toolchain
+ rustup default stable-i686-pc-windows-msvc
+ # Rust puts its shared stdlib in a secret place, but it is needed to run tests.
+ $env:Path += ";$HOME/.rustup/toolchains/stable-i686-pc-windows-msvc/bin"
+ # Need 32-bit Python for tests that need the Python dependency
+ $env:Path = "C:\hostedtoolcache\windows\Python\3.6.8\x86;C:\hostedtoolcache\windows\Python\3.6.8\x86\Scripts;$env:Path"
+}
# Set the CI env var for the meson test framework
$env:CI = '1'